<?php
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('Hreflang')) {

    class Hreflang
    {

        public function __construct()
        {

            //activate hook
            register_activation_hook(HREFLANG_FILE, array($this, 'plugin_activation'));

            //deactivate hook
            register_deactivation_hook(HREFLANG_FILE, array($this, 'plugin_deactivation'));

            // remove_action('after_plugin_row_' . HREFLANG_PLUGIN_FILE, 'wp_plugin_update_row', 10);
            // add_action('after_plugin_row_' . HREFLANG_PLUGIN_FILE, [$this, 'hl_show_update_notification'], 10, 2);
        }

        private function bail_on_activation($message, $deactivate = true)
        {
            // Output HTML error message
            echo wp_kses($message, array(
                'a' => array(
                    'href' => array(),
                    'title' => array(),
                    'target' => array()
                ),
                'strong' => array()
            ));

            if ($deactivate) {
                // Deactivate the plugin
                deactivate_plugins(plugin_basename(HREFLANG_FILE));
            }
            exit;
        }

        //triggered on activation of the plugin (called only once)
        public function plugin_activation()
        {
            if (version_compare($GLOBALS['wp_version'], HREFLANG_MINIMUM_WP_VERSION, '<')) {
                load_plugin_textdomain('hreflang-customizer');

                $message = '<strong>' . sprintf(esc_html__('Hreflang Customizer %s requires WordPress %s or higher.', 'hreflang-customizer'), HREFLANG_VERSION, HREFLANG_MINIMUM_WP_VERSION) . '</strong> ' . sprintf(__('Please <a href="%1$s" target="_blank">upgrade WordPress</a> to a current version, or downgrade to version 1.0.0 of the <a href="%2$s" target="_blank">Hreflang Customizer</a> plugin.', 'hreflang-customizer'), 'https://wordpress.org/documentation/article/updating-wordpress/', HREFLANG_WEB_DOMAIN);
                $this->bail_on_activation($message);
            } elseif (!empty($_SERVER['SCRIPT_NAME']) && false !== strpos($_SERVER['SCRIPT_NAME'], '/wp-admin/plugins.php')) {
                // add_option('Activated_Hreflang', true);
            }
        }

        //trigered on deactivation of the plugin (called only once)
        public function plugin_deactivation()
        {
            //
        }

        /**
         * Show the update notification on multisite subsites.
         *
         * @param string  $file
         * @param array   $plugin
         */
        public function hl_show_update_notification($file, $plugin)
        {
            // Return early if in the network admin, or if this is not a multisite install.
            if (is_network_admin()) {
                return;
            }

            // Allow single site admins to see that an update is available.
            if (!current_user_can('activate_plugins')) {
                return;
            }

            if (HREFLANG_PLUGIN_FILE !== $file) {
                return;
            }

            $slug = esc_attr(HREFLANG_SLUG); // Escape the slug for security.
            $active_class = in_array($file, $this->get_active_plugins(), true) ? 'active' : 'inactive';

            printf(
                '<tr class="plugin-update-tr %3$s" id="%1$s-update" data-slug="%1$s" data-plugin="%2$s">',
                $slug,
                esc_attr($file),
                // Escape the file for security.
                $active_class
            );

            $update_link = add_query_arg(
                array(
                    'action' => 'upgrade-plugin',
                    'plugin' => urlencode($file),
                ),
                self_admin_url('update.php')
            );

            $changelog_link = ''; // Provide the actual changelog link.

            echo '<td colspan="4" class="plugin-update colspanchange">';
            echo '<div class="update-message notice inline notice-warning notice-alt"><p>';
            printf(
                /* translators: 1. and 4. are opening anchor tags 2. the new plugin version 3. and 5. are closing anchor tags. */
                esc_html__('%1$sView version %2$s details%3$s or %4$supdate now%5$s.', 'hreflang-customizer'),
                '<a target="_blank" class="thickbox open-plugin-details-modal" href="' . esc_url($changelog_link) . '">',
                esc_html(HREFLANG_VERSION),
                // Use the HREFLANG_VERSION constant
                '</a>',
                '<a target="_blank" class="update-link" href="' . esc_url(wp_nonce_url($update_link, 'upgrade-plugin_' . $file)) . '">',
                '</a>'
            );

            do_action("in_plugin_update_message-{$file}", $plugin, $plugin);

            echo '</p></div></td></tr>';
        }

        /**
         * Gets the plugins active in a multisite network.
         *
         * @return array
         */
        private function get_active_plugins()
        {
            $active_plugins = (array) get_option('active_plugins');
            $active_network_plugins = (array) get_site_option('active_sitewide_plugins');

            return array_merge($active_plugins, array_keys($active_network_plugins));
        }
    }

    new Hreflang();

}
