<?php
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('Hreflang_Admin')) {

    class Hreflang_Admin
    {

        private $hreflang_languages;
        private $hreflang_license;
        public function __construct()
        {
            $this->hreflang_license = get_option('hl_license');

            add_action('admin_init', array($this, 'admin_init'));
            add_action('admin_menu', array($this, 'admin_menu'));
            add_action('admin_notices', array($this, 'display_notice'));
            add_action('admin_enqueue_scripts', array($this, 'load_resources'));

        }

        public function admin_init()
        {

            // register setting
            register_setting('hreflang_setting_group', 'hl_languages', [$this, 'hreflang_languages_callback']);

            // add settings section
            add_settings_section('hreflang_languages_section', null, [], 'hreflang-admin');
            add_settings_field('hl_languages', 'Languages', array($this, 'render_hreflang_languages_field'), 'hreflang-admin', 'hreflang_languages_section');
        }

        public function admin_menu()
        {
            add_menu_page('Hreflang', 'Hreflang', 'manage_options', HREFLANG_SLUG, array($this, 'hreflang_admin_settings_page'), 'dashicons-translation', 90);

            add_submenu_page(HREFLANG_SLUG, 'Settings', 'Settings', 'manage_options', HREFLANG_SLUG, array($this, 'hreflang_admin_settings_page'), 1);
            add_submenu_page(HREFLANG_SLUG, 'Support', 'Support', 'manage_options', 'hl-support', array($this, 'hreflang_admin_support_page'), 3);
            
        }

        // settings page
        public function hreflang_admin_settings_page()
        {
            $this->hreflang_languages = get_option('hl_languages'); ?>
            <div class="wrap">
                <?php settings_errors(); ?>
                <h1>Hreflang Setting</h1>
                <p>Select custom languages for adding a tags:</p>
                <form method="post" action="options.php">
                    <?php settings_fields('hreflang_setting_group'); ?>
                    <?php do_settings_sections('hreflang-admin'); ?>
                    <?php submit_button(); ?>
                </form>
            </div>
        <?php }

        // settings page
        public function hreflang_admin_support_page()
        {
            include_once HREFLANG_TEMPLATES_ADMIN_PAGES . '/support.php';
        }

        public function load_resources()
        {
            global $hook_suffix;

            // Enqueue Select2 script and style
            wp_enqueue_script('select2', HREFLANG_PLUGIN_URL . 'admin/js/select2.min.js', array('jquery'), HREFLANG_VERSION, true);
            wp_enqueue_style('select2-css', HREFLANG_PLUGIN_URL . 'admin/css/select2.min.css', array(), HREFLANG_VERSION);

            // Enqueue your custom admin styles and scripts
            wp_enqueue_style('hreflang-admin-styles', HREFLANG_PLUGIN_URL . 'admin/css/admin-styles.css', array('select2-css'), HREFLANG_VERSION);
            wp_enqueue_script('hreflang-admin-script', HREFLANG_PLUGIN_URL . 'admin/js/admin-script.js', array('jquery', 'select2'), HREFLANG_VERSION, true);
        }

        // admin notice
        public function display_notice()
        {
            $hl_languages = get_option('hl_languages');
            if (!is_array($hl_languages)) { ?>
                <div class="notice notice-warning is-dismissible">
                    <p>
                        <?php
                        printf(
                            esc_html__('Configure the Hreflang customizer plugin and improve your website\'s SEO performance. %1$sConfigure Now!%2$s', 'hreflang-customizer'),
                            '<a href="' . esc_url(admin_url('admin.php?page=hreflang-settings')) . '">',
                            '</a>'
                        );
                        ?>
                    </p>
                </div>
            <?php }
        }

        // Render languages input
        public function render_hreflang_languages_field()
        {
            // Get the saved options
            $hl_languages = (isset($this->hreflang_languages) && is_array($this->hreflang_languages)) ? $this->hreflang_languages : [];

            // Define the available options
            $available_options = hreflang_get_languages();

            // Output the multi-select field
            echo '<select multiple name="hl_languages[]" class="hl-multiple regular-text">';
            foreach ($available_options as $options) {
                foreach ($options as $option) {
                    $code = esc_attr($option['code']); // Sanitize the code
                    $name = esc_html($option['name']); // Sanitize the name
                    $selected = in_array($code, $hl_languages) ? 'selected' : '';

                    printf(
                        '<option value="%s" %s>%s (%s)</option>',
                        $code,
                        $selected,
                        $name,
                        $code
                    );
                }
            }
            echo '</select>';
        }

        // callback languageies input
        public function hreflang_languages_callback($options)
        {
            return $options;
        }

    }
}
