<?php

if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('HreflangTags')) {

    class HreflangTags
    {

        protected $hl_languages;

        public function __construct()
        {
            add_action('wp_head', array($this, 'init_weglot'));
            $this->hl_languages = $this->init_custom_languages();
        }

        private function init_custom_languages()
        {
            $hl_custom_lang = [];
            $hl_languages = get_option('hl_languages');
            if (!empty($hl_languages) && is_array($hl_languages)) {
                $all_languageies = hreflang_get_languages();
                foreach ($all_languageies as $lk => $languageies) {
                    foreach ($languageies as $language) {
                        if (in_array($language['code'], $hl_languages)) {
                            $hl_custom_lang[$lk][] = $language;
                        }
                    }
                }
                return $hl_custom_lang;
            }
            return $hl_custom_lang;
        }

        /**
         * Initialize Weglot alternate links for SEO.
         */
        public function init_weglot()
        {
            if (function_exists('weglot_get_current_language')) {
                $weglot_languages_available = weglot_get_request_url_service();
                $urls = $weglot_languages_available->get_weglot_url()->getAllUrls();

                foreach ($urls as $url) {
                    $lcode = $url['language']->getExternalCode();

                    if (isset($this->hl_languages[$lcode]) && !$url['excluded']) {
                        foreach ($this->hl_languages[$lcode] as $nlag) {
                            if ($nlag['code'] != $lcode) {
                                $alternate_url = strtok(esc_url($url['url']), '?');
                                $alternate_code = esc_attr($nlag['code']);

                                // Output alternate language link tag
                                printf(
                                    '<link rel="alternate" href="%s" hreflang="%s" />' . "\n",
                                    $alternate_url,
                                    $alternate_code
                                );
                            }
                        }
                    }
                }
            }
        }
    }

    new HreflangTags();

}
